@@ -34,7 +34,7 @@ from gitlab.exceptions import *  # noqa
 from gitlab.objects import *  # noqa
 
 __title__ = 'python-gitlab'
-__version__ = '0.19'
+__version__ = '0.20'
 __author__ = 'Gauvain Pocentek'
 __email__ = 'gauvain@pocentek.net'
 __license__ = 'LGPL3'
@@ -91,6 +91,7 @@ class Gitlab(object):
 
         self.broadcastmessages = BroadcastMessageManager(self)
         self.keys = KeyManager(self)
+        self.deploykeys = DeployKeyManager(self)
         self.gitlabciymls = GitlabciymlManager(self)
         self.gitignores = GitignoreManager(self)
         self.groups = GroupManager(self)
@@ -111,8 +112,8 @@ class Gitlab(object):
         # build the "submanagers"
         for parent_cls in six.itervalues(globals()):
             if (not inspect.isclass(parent_cls)
-               or not issubclass(parent_cls, GitlabObject)
-               or parent_cls == CurrentUser):
+                or not issubclass(parent_cls, GitlabObject)
+                    or parent_cls == CurrentUser):
                 continue
 
             if not parent_cls.managers:
@@ -311,11 +312,13 @@ class Gitlab(object):
         params = extra_attrs.copy()
         params.update(kwargs.copy())
 
-        get_all_results = kwargs.get('all', False)
+        catch_recursion_limit = kwargs.get('safe_all', False)
+        get_all_results = (kwargs.get('all', False) is True
+                           or catch_recursion_limit)
 
         # Remove these keys to avoid breaking the listing (urls will get too
         # long otherwise)
-        for key in ['all', 'next_url']:
+        for key in ['all', 'next_url', 'safe_all']:
             if key in params:
                 del params[key]
 
@@ -333,11 +336,20 @@ class Gitlab(object):
 
         results = [cls(self, item, **params) for item in r.json()
                    if item is not None]
-        if ('next' in r.links and 'url' in r.links['next']
-           and get_all_results is True):
-            args = kwargs.copy()
-            args['next_url'] = r.links['next']['url']
-            results.extend(self.list(cls, **args))
+        try:
+            if ('next' in r.links and 'url' in r.links['next']
+                    and get_all_results):
+                args = kwargs.copy()
+                args.update(extra_attrs)
+                args['next_url'] = r.links['next']['url']
+                results.extend(self.list(cls, **args))
+        except Exception as e:
+            # Catch the recursion limit exception if the 'safe_all'
+            # kwarg was provided
+            if not (catch_recursion_limit and
+                    "maximum recursion depth exceeded" in str(e)):
+                raise e
+
         return results
 
     def _raw_post(self, path_, data=None, content_type=None, **kwargs):
