@@ -297,6 +297,11 @@ class GitlabObject(object):
             return
 
         for k, v in data.items():
+            # If a k attribute already exists and is a Manager, do nothing (see
+            # https://github.com/gpocentek/python-gitlab/issues/209)
+            if isinstance(getattr(self, k, None), BaseManager):
+                continue
+
             if isinstance(v, list):
                 self.__dict__[k] = []
                 for i in v:
@@ -797,11 +802,28 @@ class Key(GitlabObject):
     canUpdate = False
     canDelete = False
 
+    def __init__(self, *args, **kwargs):
+        warnings.warn("`Key` is deprecated, use `DeployKey` instead",
+                      DeprecationWarning)
+        super(Key, self).__init__(*args, **kwargs)
+
 
 class KeyManager(BaseManager):
     obj_cls = Key
 
 
+class DeployKey(GitlabObject):
+    _url = '/deploy_keys'
+    canGet = 'from_list'
+    canCreate = False
+    canUpdate = False
+    canDelete = False
+
+
+class DeployKeyManager(BaseManager):
+    obj_cls = DeployKey
+
+
 class NotificationSettings(GitlabObject):
     _url = '/notification_settings'
     _id_in_update_url = False
@@ -893,20 +915,6 @@ class GroupNotificationSettingsManager(BaseManager):
     obj_cls = GroupNotificationSettings
 
 
-class GroupProject(GitlabObject):
-    _url = '/groups/%(group_id)s/projects'
-    canGet = 'from_list'
-    canCreate = False
-    canDelete = False
-    canUpdate = False
-    optionalListAttrs = ['archived', 'visibility', 'order_by', 'sort',
-                         'search', 'ci_enabled_first']
-
-
-class GroupProjectManager(BaseManager):
-    obj_cls = GroupProject
-
-
 class GroupAccessRequest(GitlabObject):
     _url = '/groups/%(group_id)s/access_requests'
     canGet = 'from_list'
@@ -935,65 +943,6 @@ class GroupAccessRequestManager(BaseManager):
     obj_cls = GroupAccessRequest
 
 
-class Group(GitlabObject):
-    _url = '/groups'
-    _constructorTypes = {'projects': 'Project'}
-    requiredCreateAttrs = ['name', 'path']
-    optionalCreateAttrs = ['description', 'visibility_level']
-    optionalUpdateAttrs = ['name', 'path', 'description', 'visibility_level']
-    shortPrintAttr = 'name'
-    managers = (
-        ('accessrequests', GroupAccessRequestManager, [('group_id', 'id')]),
-        ('members', GroupMemberManager, [('group_id', 'id')]),
-        ('notificationsettings', GroupNotificationSettingsManager,
-         [('group_id', 'id')]),
-        ('projects', GroupProjectManager, [('group_id', 'id')]),
-        ('issues', GroupIssueManager, [('group_id', 'id')]),
-    )
-
-    GUEST_ACCESS = gitlab.GUEST_ACCESS
-    REPORTER_ACCESS = gitlab.REPORTER_ACCESS
-    DEVELOPER_ACCESS = gitlab.DEVELOPER_ACCESS
-    MASTER_ACCESS = gitlab.MASTER_ACCESS
-    OWNER_ACCESS = gitlab.OWNER_ACCESS
-
-    VISIBILITY_PRIVATE = gitlab.VISIBILITY_PRIVATE
-    VISIBILITY_INTERNAL = gitlab.VISIBILITY_INTERNAL
-    VISIBILITY_PUBLIC = gitlab.VISIBILITY_PUBLIC
-
-    def transfer_project(self, id, **kwargs):
-        """Transfers a project to this new groups.
-
-        Attrs:
-            id (int): ID of the project to transfer.
-
-        Raises:
-            GitlabConnectionError: If the server cannot be reached.
-            GitlabTransferProjectError: If the server fails to perform the
-                request.
-        """
-        url = '/groups/%d/projects/%d' % (self.id, id)
-        r = self.gitlab._raw_post(url, None, **kwargs)
-        raise_error_from_response(r, GitlabTransferProjectError, 201)
-
-
-class GroupManager(BaseManager):
-    obj_cls = Group
-
-    def search(self, query, **kwargs):
-        """Searches groups by name.
-
-        Args:
-            query (str): The search string
-            all (bool): If True, return all the items, without pagination
-
-        Returns:
-            list(Group): a list of matching groups.
-        """
-        url = '/groups?search=' + query
-        return self.gitlab._raw_list(url, self.obj_cls, **kwargs)
-
-
 class Hook(GitlabObject):
     _url = '/hooks'
     canUpdate = False
@@ -1137,7 +1086,7 @@ class ProjectBranch(GitlabObject):
     requiredCreateAttrs = ['branch_name', 'ref']
 
     def protect(self, protect=True, **kwargs):
-        """Protects the project."""
+        """Protects the branch."""
         url = self._url % {'project_id': self.project_id}
         action = 'protect' if protect else 'unprotect'
         url = "%s/%s/%s" % (url, self.name, action)
@@ -1150,7 +1099,7 @@ class ProjectBranch(GitlabObject):
             del self.protected
 
     def unprotect(self, **kwargs):
-        """Unprotects the project."""
+        """Unprotects the branch."""
         self.protect(False, **kwargs)
 
 
@@ -1353,6 +1302,23 @@ class ProjectCommit(GitlabObject):
                                      {'project_id': self.project_id},
                                      **kwargs)
 
+    def cherry_pick(self, branch, **kwargs):
+        """Cherry-pick a commit into a branch.
+
+        Args:
+            branch (str): Name of target branch.
+
+        Raises:
+            GitlabCherryPickError: If the cherry pick could not be applied.
+        """
+        url = ('/projects/%s/repository/commits/%s/cherry_pick' %
+               (self.project_id, self.id))
+
+        r = self.gitlab._raw_post(url, data={'project_id': self.project_id,
+                                             'branch': branch}, **kwargs)
+        errors = {400: GitlabCherryPickError}
+        raise_error_from_response(r, errors, expected_code=201)
+
 
 class ProjectCommitManager(BaseManager):
     obj_cls = ProjectCommit
@@ -1523,6 +1489,69 @@ class ProjectIssue(GitlabObject):
         r = self.gitlab._raw_post(url, **kwargs)
         raise_error_from_response(r, GitlabTodoError, [201, 304])
 
+    def time_stats(self, **kwargs):
+        """Get time stats for the issue.
+
+        Raises:
+            GitlabConnectionError: If the server cannot be reached.
+        """
+        url = ('/projects/%(project_id)s/issues/%(issue_id)s/time_stats' %
+               {'project_id': self.project_id, 'issue_id': self.id})
+        r = self.gitlab._raw_get(url, **kwargs)
+        raise_error_from_response(r, GitlabGetError)
+        return r.json()
+
+    def time_estimate(self, **kwargs):
+        """Set an estimated time of work for the issue.
+
+        Raises:
+            GitlabConnectionError: If the server cannot be reached.
+        """
+        url = ('/projects/%(project_id)s/issues/%(issue_id)s/time_estimate' %
+               {'project_id': self.project_id, 'issue_id': self.id})
+        r = self.gitlab._raw_post(url, **kwargs)
+        raise_error_from_response(r, GitlabTimeTrackingError, 201)
+        return r.json()
+
+    def reset_time_estimate(self, **kwargs):
+        """Resets estimated time for the issue to 0 seconds.
+
+        Raises:
+            GitlabConnectionError: If the server cannot be reached.
+        """
+        url = ('/projects/%(project_id)s/issues/%(issue_id)s/'
+               'reset_time_estimate' %
+               {'project_id': self.project_id, 'issue_id': self.id})
+        r = self.gitlab._raw_post(url, **kwargs)
+        raise_error_from_response(r, GitlabTimeTrackingError, 200)
+        return r.json()
+
+    def add_spent_time(self, **kwargs):
+        """Set an estimated time of work for the issue.
+
+        Raises:
+            GitlabConnectionError: If the server cannot be reached.
+        """
+        url = ('/projects/%(project_id)s/issues/%(issue_id)s/'
+               'add_spent_time' %
+               {'project_id': self.project_id, 'issue_id': self.id})
+        r = self.gitlab._raw_post(url, **kwargs)
+        raise_error_from_response(r, GitlabTimeTrackingError, 200)
+        return r.json()
+
+    def reset_spent_time(self, **kwargs):
+        """Set an estimated time of work for the issue.
+
+        Raises:
+            GitlabConnectionError: If the server cannot be reached.
+        """
+        url = ('/projects/%(project_id)s/issues/%(issue_id)s/'
+               'reset_spent_time' %
+               {'project_id': self.project_id, 'issue_id': self.id})
+        r = self.gitlab._raw_post(url, **kwargs)
+        raise_error_from_response(r, GitlabTimeTrackingError, 200)
+        return r.json()
+
 
 class ProjectIssueManager(BaseManager):
     obj_cls = ProjectIssue
@@ -1630,7 +1659,6 @@ class ProjectMergeRequestDiffManager(BaseManager):
 class ProjectMergeRequestNote(GitlabObject):
     _url = '/projects/%(project_id)s/merge_requests/%(merge_request_id)s/notes'
     _constructorTypes = {'author': 'User'}
-    canDelete = False
     requiredUrlAttrs = ['project_id', 'merge_request_id']
     requiredCreateAttrs = ['body']
 
@@ -1645,7 +1673,7 @@ class ProjectMergeRequest(GitlabObject):
     requiredUrlAttrs = ['project_id']
     requiredCreateAttrs = ['source_branch', 'target_branch', 'title']
     optionalCreateAttrs = ['assignee_id', 'description', 'target_project_id',
-                           'labels', 'milestone_id']
+                           'labels', 'milestone_id', 'remove_source_branch']
     optionalUpdateAttrs = ['target_branch', 'assignee_id', 'title',
                            'description', 'state_event', 'labels',
                            'milestone_id']
@@ -1908,10 +1936,14 @@ class ProjectFileManager(BaseManager):
 
 class ProjectPipeline(GitlabObject):
     _url = '/projects/%(project_id)s/pipelines'
-    canCreate = False
+    _create_url = '/projects/%(project_id)s/pipeline'
+
     canUpdate = False
     canDelete = False
 
+    requiredUrlAttrs = ['project_id']
+    requiredCreateAttrs = ['ref']
+
     def retry(self, **kwargs):
         """Retries failed builds in a pipeline.
 
@@ -2620,6 +2652,81 @@ class ProjectManager(BaseManager):
         return self.gitlab._raw_list("/projects/starred", Project, **kwargs)
 
 
+class GroupProject(Project):
+    _url = '/groups/%(group_id)s/projects'
+    canGet = 'from_list'
+    canCreate = False
+    canDelete = False
+    canUpdate = False
+    optionalListAttrs = ['archived', 'visibility', 'order_by', 'sort',
+                         'search', 'ci_enabled_first']
+
+    def __init__(self, *args, **kwargs):
+        Project.__init__(self, *args, **kwargs)
+
+
+class GroupProjectManager(BaseManager):
+    obj_cls = GroupProject
+
+
+class Group(GitlabObject):
+    _url = '/groups'
+    requiredCreateAttrs = ['name', 'path']
+    optionalCreateAttrs = ['description', 'visibility_level']
+    optionalUpdateAttrs = ['name', 'path', 'description', 'visibility_level']
+    shortPrintAttr = 'name'
+    managers = (
+        ('accessrequests', GroupAccessRequestManager, [('group_id', 'id')]),
+        ('members', GroupMemberManager, [('group_id', 'id')]),
+        ('notificationsettings', GroupNotificationSettingsManager,
+         [('group_id', 'id')]),
+        ('projects', GroupProjectManager, [('group_id', 'id')]),
+        ('issues', GroupIssueManager, [('group_id', 'id')]),
+    )
+
+    GUEST_ACCESS = gitlab.GUEST_ACCESS
+    REPORTER_ACCESS = gitlab.REPORTER_ACCESS
+    DEVELOPER_ACCESS = gitlab.DEVELOPER_ACCESS
+    MASTER_ACCESS = gitlab.MASTER_ACCESS
+    OWNER_ACCESS = gitlab.OWNER_ACCESS
+
+    VISIBILITY_PRIVATE = gitlab.VISIBILITY_PRIVATE
+    VISIBILITY_INTERNAL = gitlab.VISIBILITY_INTERNAL
+    VISIBILITY_PUBLIC = gitlab.VISIBILITY_PUBLIC
+
+    def transfer_project(self, id, **kwargs):
+        """Transfers a project to this new groups.
+
+        Attrs:
+            id (int): ID of the project to transfer.
+
+        Raises:
+            GitlabConnectionError: If the server cannot be reached.
+            GitlabTransferProjectError: If the server fails to perform the
+                request.
+        """
+        url = '/groups/%d/projects/%d' % (self.id, id)
+        r = self.gitlab._raw_post(url, None, **kwargs)
+        raise_error_from_response(r, GitlabTransferProjectError, 201)
+
+
+class GroupManager(BaseManager):
+    obj_cls = Group
+
+    def search(self, query, **kwargs):
+        """Searches groups by name.
+
+        Args:
+            query (str): The search string
+            all (bool): If True, return all the items, without pagination
+
+        Returns:
+            list(Group): a list of matching groups.
+        """
+        url = '/groups?search=' + query
+        return self.gitlab._raw_list(url, self.obj_cls, **kwargs)
+
+
 class TeamMemberManager(BaseManager):
     obj_cls = TeamMember
 
